==> paraview-v0.6.0.zip: paraview-v0.6.0/ParaView/ParaView/vtkPVSourceWidget.h <==
/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkPVSourceWidget.h
  Language:  C++
  Date:      $Date$
  Version:   $Revision$

Copyright (c) 2000-2001 Kitware Inc. 469 Clifton Corporate Parkway,
Clifton Park, NY, 12065, USA.
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.

 * Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.

 * Neither the name of Kitware nor the names of any contributors may be used
   to endorse or promote products derived from this software without specific 
   prior written permission.

 * Modified source versions must be plainly marked as such, and must not be
   misrepresented as being the original software.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
// .NAME vtkPVSourceWidget - superclass for widgets which contain a vtk source
// .SECTION Description
// The subclasses of this widget contain a vtkSource. This source (which
// is created on all processes) can be used as input or source to 
// filters.

#ifndef __vtkPVSourceWidget_h
#define __vtkPVSourceWidget_h

#include "vtkPVObjectWidget.h"

class VTK_EXPORT vtkPVSourceWidget : public vtkPVObjectWidget
{
public:
  vtkTypeRevisionMacro(vtkPVSourceWidget, vtkPVObjectWidget);
  void PrintSelf(ostream& os, vtkIndent indent);

  // Description:
  // The Tcl name of the contained VTK source.
  vtkGetStringMacro(SourceTclName);

  // Description:
  // The Tcl name of the output of the contained VTK source.
  vtkGetStringMacro(OutputTclName);

  // Description:
  // A method for saving a widget into a VTK Tcl script.
  virtual void SaveInTclScript(ofstream *file);

protected:
  vtkPVSourceWidget();
  ~vtkPVSourceWidget();

  char* SourceTclName;
  vtkSetStringMacro(SourceTclName);

  char* OutputTclName;
  vtkSetStringMacro(OutputTclName);

  vtkPVSourceWidget(const vtkPVSourceWidget&); // Not implemented
  void operator=(const vtkPVSourceWidget&); // Not implemented

};

#endif

==> paraview-v1.0.4.zip: paraview-v1.0.4/ParaView/ParaView/vtkPVSourceWidget.h <==
/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkPVSourceWidget.h
  Language:  C++
  Date:      $Date$
  Version:   $Revision$

Copyright (c) 2000-2001 Kitware Inc. 469 Clifton Corporate Parkway,
Clifton Park, NY, 12065, USA.
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.

 * Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.

 * Neither the name of Kitware nor the names of any contributors may be used
   to endorse or promote products derived from this software without specific 
   prior written permission.

 * Modified source versions must be plainly marked as such, and must not be
   misrepresented as being the original software.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
// .NAME vtkPVSourceWidget - superclass for widgets which contain a vtk source
// .SECTION Description
// The subclasses of this widget contain a vtkSource. This source (which
// is created on all processes) can be used as input or source to 
// filters.

#ifndef __vtkPVSourceWidget_h
#define __vtkPVSourceWidget_h

#include "vtkPVObjectWidget.h"

class VTK_EXPORT vtkPVSourceWidget : public vtkPVObjectWidget
{
public:
  vtkTypeRevisionMacro(vtkPVSourceWidget, vtkPVObjectWidget);
  void PrintSelf(ostream& os, vtkIndent indent);

  // Description:
  // The Tcl name of the contained VTK source.
  vtkGetStringMacro(SourceTclName);

  // Description:
  // The Tcl name of the output of the contained VTK source.
  vtkGetStringMacro(OutputTclName);

  // Description:
  // A method for saving a widget into a VTK Tcl script.
  virtual void SaveInBatchScript(ofstream *file);

protected:
  vtkPVSourceWidget();
  ~vtkPVSourceWidget();

  char* SourceTclName;
  vtkSetStringMacro(SourceTclName);

  char* OutputTclName;
  vtkSetStringMacro(OutputTclName);

  // Description:
  // A method for saving a widget into a VTK Tcl script.
  virtual void SaveInBatchScriptForPart(ofstream *file, const char* sourceTclName);

  vtkPVSourceWidget(const vtkPVSourceWidget&); // Not implemented
  void operator=(const vtkPVSourceWidget&); // Not implemented

};

#endif
